@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -19,32 +19,57 @@ import github.NamedUser
 
 
 class CommitStatus(github.GithubObject.BasicGithubObject):
+    """
+    This class represents CommitStatuss as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def created_at(self):
+        """
+        :type: datetime.datetime
+        """
         return self._NoneIfNotSet(self._created_at)
 
     @property
     def creator(self):
+        """
+        :type: :class:`github.NamedUser.NamedUser`
+        """
         return self._NoneIfNotSet(self._creator)
 
     @property
     def description(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._description)
 
     @property
     def id(self):
+        """
+        :type: integer
+        """
         return self._NoneIfNotSet(self._id)
 
     @property
     def state(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._state)
 
     @property
     def target_url(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._target_url)
 
     @property
     def updated_at(self):
+        """
+        :type: datetime.datetime
+        """
         return self._NoneIfNotSet(self._updated_at)
 
     def _initAttributes(self):
