@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -17,20 +17,36 @@ import github.GithubObject
 
 
 class HookDescription(github.GithubObject.BasicGithubObject):
+    """
+    This class represents HookDescriptions as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def events(self):
+        """
+        :type: list of string
+        """
         return self._NoneIfNotSet(self._events)
 
     @property
     def name(self):
+        """
+        :type: string
+        """
         return self._NoneIfNotSet(self._name)
 
     @property
     def schema(self):
+        """
+        :type: list of list of string
+        """
         return self._NoneIfNotSet(self._schema)
 
     @property
     def supported_events(self):
+        """
+        :type: list of string
+        """
         return self._NoneIfNotSet(self._supported_events)
 
     def _initAttributes(self):
