@@ -3,7 +3,7 @@
 # Copyright 2012 Vincent Jacques
 # vincent@vincent-jacques.net
 
-# This file is part of PyGithub. http://vincent-jacques.net/PyGithub
+# This file is part of PyGithub. http://jacquev6.github.com/PyGithub/
 
 # PyGithub is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License
 # as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
@@ -19,22 +19,39 @@ import github.GithubObject
 
 
 class Label(github.GithubObject.GithubObject):
+    """
+    This class represents Labels as returned for example by http://developer.github.com/v3/todo
+    """
+
     @property
     def color(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._color)
         return self._NoneIfNotSet(self._color)
 
     @property
     def name(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._name)
         return self._NoneIfNotSet(self._name)
 
     @property
     def url(self):
+        """
+        :type: string
+        """
         self._completeIfNotSet(self._url)
         return self._NoneIfNotSet(self._url)
 
     def delete(self):
+        """
+        :calls: `DELETE /repos/:user/:repo/labels/:name <http://developer.github.com/v3/todo>`_
+        :rtype: None
+        """
         headers, data = self._requester.requestJsonAndCheck(
             "DELETE",
             self.url,
@@ -43,6 +60,12 @@ class Label(github.GithubObject.GithubObject):
         )
 
     def edit(self, name, color):
+        """
+        :calls: `PATCH /repos/:user/:repo/labels/:name <http://developer.github.com/v3/todo>`_
+        :param name: string
+        :param color: string
+        :rtype: None
+        """
         assert isinstance(name, (str, unicode)), name
         assert isinstance(color, (str, unicode)), color
         post_parameters = {
